@@ -1,27 +1,20 @@
-#[macro_use]
-extern crate slog;
-extern crate slog_async;
-extern crate slog_envlogger;
-extern crate slog_scope;
-extern crate slog_stdlog;
-extern crate slog_term;
-
 use env_applier::EnvApply;
-use slog::{Drain, FnValue};
 use std::env;
 use std::io;
+use tracing_futures::WithSubscriber;
+use tracing_subscriber;
+use tracing_subscriber::util::SubscriberInitExt;
+use tracing_subscriber::EnvFilter;
 
 #[tokio::main]
 async fn main() -> io::Result<()> {
-    let decorator = slog_term::TermDecorator::new().build();
-    let drain = slog_term::FullFormat::new(decorator).build().fuse();
-    let drain = slog_envlogger::new(drain);
-    let drain = slog_async::Async::default(drain).fuse();
-    let logger = slog::Logger::root(
-        drain.fuse(),
-        o!("file" => FnValue(move |info| {format!("{}:{}",info.file(),info.line())})),
-    );
-    let _scope_guard = slog_scope::set_global_logger(logger);
+    let (non_blocking, _guard) = tracing_appender::non_blocking(io::stdout());
+    let subscriber = tracing_subscriber::fmt()
+        .with_writer(non_blocking)
+        .with_env_filter(EnvFilter::from_default_env())
+        .finish();
+
+    tracing_subscriber::registry().init();
 
     let config = r#"
     [
@@ -35,9 +28,13 @@ async fn main() -> io::Result<()> {
     "#;
 
     let config_resolved = env::Vars::apply(config.to_string());
-    chewdata::exec(serde_json::from_str(config_resolved.as_str())?, None).await?;
+    chewdata::exec(serde_json::from_str(config_resolved.as_str())?, None)
+        .with_subscriber(subscriber)
+        .await?;
 
-    info!(slog_scope::logger(), "Check the files `./data/out/cascade_file1.json` and `./data/out/cascade_file2.json`");
+    tracing::info!(
+        "Check the files `./data/out/cascade_file1.json` and `./data/out/cascade_file2.json`"
+    );
 
     Ok(())
 }
