@@ -32,7 +32,7 @@ impl Updater for Tera {
         input_name: String,
         output_name: String,
     ) -> io::Result<Value> {
-        debug!(slog_scope::logger(), "Update"; "input" => format!("{}", object), "updater" => format!("{}", self));
+        trace!(input = format!("{}", object).as_str(), updater = format!("{}", self).as_str(), "Update");
         let mut engine = Tera::engine();
         let mut context = tera::Context::new();
         context.insert(input_name, &object);
@@ -45,7 +45,7 @@ impl Updater for Tera {
 
         let mut json_value = Value::default();
         for action in actions {
-            debug!(slog_scope::logger(), "Field fetch into the pattern collection"; "field" => &action.field);
+            trace!(field = action.field.as_str(), "Field fetch into the pattern collection");
             context.insert(output_name.clone(), &json_value.clone());
 
             let mut field_new_value = Value::default();
@@ -72,19 +72,19 @@ impl Updater for Tera {
                             ),
                         )),
                     }?;
-                    debug!(slog_scope::logger(), "Field value before resolved it"; "value" => render_result.to_string());
+                    trace!(value = render_result.as_str(),  "Field value before resolved it");
                     field_new_value = Value::resolve(render_result);
-                    debug!(slog_scope::logger(), "Field value after resolved it"; "value" => format!("{}", field_new_value));
+                    trace!(value = format!("{}", field_new_value).as_str(),  "Field value after resolved it");
                 }
                 None => (),
             };
 
             let json_pointer = action.field.clone().to_json_pointer();
 
-            debug!(slog_scope::logger(), "{} the new field", action.action_type;
-                "output" => format!("{}", json_value),
-                "jpointer" => json_pointer.to_string(),
-                "data to add" => format!("{}", field_new_value)
+            trace!(output = format!("{}", json_value).as_str(),
+                jpointer = json_pointer.to_string().as_str(),
+                "data to add" = format!("{}", field_new_value).as_str(),
+                "{} the new field", action.action_type
             );
 
             match action.action_type {
@@ -101,7 +101,7 @@ impl Updater for Tera {
             }
         }
 
-        debug!(slog_scope::logger(), "Update ended"; "output" => format!("{}", json_value));
+        trace!(output = format!("{}", json_value).as_str(),  "Update ended");
         Ok(json_value)
     }
 }
